# Run tests in check section
#bcond_without check

# £global debug_package   %{nil}
%global goipath         github.com/ipfs/go-ipfs
%global provider        github.com
%global project         ipfs
%global repo            go-ipfs
# https://github.com/ipfs/go-ipfs
%global forgeurl        https://%{provider}/%{project}/%{repo}
Version:                0.8.0


%global common_description %{expand:
What is IPFS?

IPFS is a global, versioned, peer-to-peer filesystem. It combines good ideas
from previous systems such Git, BitTorrent, Kademlia, SFS, and the Web. It is
like a single bittorrent swarm, exchanging git objects. IPFS provides an
interface as simple as the HTTP web, but with permanence built in. You can also
mount the world at /ipfs.

For more info see: https://docs.ipfs.io/introduction/overview/

Before opening an issue, consider using one of the following locations to
ensure you are opening your thread in the right place:

    go-ipfs implementation bugs in this repo.
    Documentation issues in ipfs/docs issues.
    IPFS design in ipfs/specs issues.
    Exploration of new ideas in ipfs/notes issues.
    Ask questions and meet the rest of the community at the IPFS Forum.}

    
%global godeveldescription %{expand:
%{common_description}
 
This package contains the source code needed for building packages that import
the %{goipath} Go namespace.}


%global golicenses      LICENSE-APACHE LICENSE-MIT
%global godocs          README.md CHANGELOG.md CONTRIBUTING.md

%gometa


Name:       %{goname}
Release:    %mkrel 1
Summary:    IPFS implementation in Go
License:    MIT and ASL-v2
Group:      Development/Other
URL:        %{gourl}
# Source0:    %{gosource}
Source0:    %{forgeurl}/releases/download/v%{version}/%{repo}-source.tar.gz
#/%{repo}-%{version}.tar.gz


BuildRequires:  golang
#Not before version 5.0.0
BuildRequires:  pkgconfig(systemd)
Requires:       systemd-units


%description
%{common_description}


%package    devel
BuildArch:  noarch
Summary:    %{summary}

%description devel
%{godeveldescription}



%prep
#Here, gosetup does not work as it decompress folder directly inside BUILD without subdirectory.
%setup -q %forgesetupargs -c %{repo}-%{version}
%goprep -k -e 
# fix vendor not found
cp -rl ./vendor/* _build/src/
rm -r ./vendor


%build
GOTAGS=openssl %gobuild -o _bin/ipfs ./cmd/ipfs
%gobuild -o _bin/ipfswatch ./cmd/ipfswatch
%gobuild -o _bin/seccat ./cmd/seccat


%install
%goinstall
# # £goinstall _bin/app
install -d -p %{buildroot}%{_bindir}
install -p -m 0755 _bin/ipfs %{buildroot}%{_bindir}
install -p -m 0755 _bin/ipfswatch %{buildroot}%{_bindir}
install -p -m 0755 _bin/seccat %{buildroot}%{_bindir}
#Autocompletion
install -d %{buildroot}%{_sysconfdir}/bash_completion.d
install -p -m 644 misc/completion/ipfs-completion.bash %{buildroot}%{_sysconfdir}/bash_completion.d
#Systemd-service
install -d %{buildroot}%{_unitdir}
install -p -m 644 misc/systemd/ipfs-api.socket     %{buildroot}%{_unitdir}
install -p -m 644 misc/systemd/ipfs-gateway.socket %{buildroot}%{_unitdir}
install -p -m 644 misc/systemd/ipfs.service        %{buildroot}%{_unitdir}

%if %{with check}
%check
%gocheck
%endif


%files
%license %{golicenses}
%doc %{godocs}
%{_bindir}/ipfs
%{_bindir}/ipfswatch
%{_bindir}/seccat
%dir %{_sysconfdir}/bash_completion.d
%{_sysconfdir}/bash_completion.d/ipfs-completion.bash
%{_unitdir}/ipfs-api.socket
%{_unitdir}/ipfs-gateway.socket
%{_unitdir}/ipfs.service


%files devel -f devel.file-list
%license %{golicenses}
%doc %{godocs}
